@@ -1,5 +1,9 @@
+# frozen_string_literal: true
+
 require 'fileutils'
 require 'pathname'
+require 'fakefs/pry'
+require 'fakefs/irb'
 require 'fakefs/base'
 require 'fakefs/fake/file'
 require 'fakefs/fake/dir'
@@ -11,5 +15,6 @@ require 'fakefs/file'
 require 'fakefs/file_test'
 require 'fakefs/dir'
 require 'fakefs/globber'
+require 'fakefs/io'
 require 'fakefs/pathname'
 require 'fakefs/kernel'
