@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'test_helper'
 
 require 'irb'
@@ -12,9 +14,10 @@ class IrbTest < Minitest::Test
 
   def teardown
     FakeFS.deactivate!
+    FakeFS::FileSystem.clear
   end
 
   def test_setup_irb
-    assert_nil IRB.setup(binding.source_location[0], argv: [])
+    assert_includes [nil, true], IRB.setup(binding.source_location[0], argv: [])
   end
 end
