@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require_relative 'test_helper'
 
 # Kernel test class
@@ -6,17 +8,22 @@ class KernelTest < Minitest::Test
 
   def teardown
     FakeFS.deactivate!
+    FakeFS::FileSystem.clear
   end
 
   def test_can_exec_normally
-    out = open("|echo 'foo'")
-    assert_equal "foo\n", out.gets
+    silence_warnings do
+      out = open("|echo 'foo'")
+      assert_equal "foo\n", out.gets
+    end
   end
 
   def test_fake_kernel_can_create_subprocesses
     FakeFS do
-      out = open("|echo 'foo'")
-      assert_equal "foo\n", out.gets
+      silence_warnings do
+        out = open("|echo 'foo'")
+        assert_equal "foo\n", out.gets
+      end
     end
   end
 
@@ -48,8 +55,10 @@ class KernelTest < Minitest::Test
   end
 
   def test_can_exec_normally2
-    out = open("|echo 'foo'")
-    assert_equal "foo\n", out.gets
+    silence_warnings do
+      out = open("|echo 'foo'")
+      assert_equal "foo\n", out.gets
+    end
   end
 
   def test_kernel_open_can_handle_kwargs_after_deactivation
